@@ -30,7 +30,7 @@ class XmlExporter(AbstractExporter):
         for xml_item in xml_inputs:
             # generate the title document with the sha
             document_name_with_sha = AbstractExporter.get_title_document(
-                xml_item["title"], xml_item["xml_content"]
+                xml_item.title, xml_item.xml_content
             )
             transform_result = TransformResult()
             # set the document name to the collection
@@ -39,11 +39,13 @@ class XmlExporter(AbstractExporter):
             transform_result_content = TransformResultContent()
             transform_result_content.file_name = document_name_with_sha
             # sets the content
-            transform_result_content.content_converted = xml_item["xml_content"]
+            transform_result_content.content_converted = xml_item.xml_content
             # sets the extension
             transform_result_content.content_extension = self.extension
             # add the content to the list of content
-            transform_result.transform_result_content.append(transform_result_content)
+            transform_result.transform_result_content.append(
+                transform_result_content
+            )
             # add the result to the list of result
             results_transform.append(transform_result)
         return results_transform
