@@ -1,7 +1,7 @@
 """Units tests for exporter rest api
 """
 from django.test import SimpleTestCase
-from mock.mock import patch
+from unittest.mock import patch
 from rest_framework import status
 
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
@@ -19,7 +19,9 @@ class TestGetExporterList(SimpleTestCase):
         self.data = None
 
     @patch.object(Exporter, "get_all")
-    def test_get_returns_status_200_with_no_permission_needed(self, mock_get_all):
+    def test_get_returns_status_200_with_no_permission_needed(
+        self, mock_get_all
+    ):
         """test_get_returns_status_200_with_no_permission_needed"""
         # Arrange
         user = create_mock_user("0")
