@@ -56,3 +56,6 @@ DATABASES = {
 DEFAULT_AUTO_FIELD = "django.db.models.AutoField"
 CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT = False
 CELERYBEAT_SCHEDULER = "django_celery_beat.schedulers:DatabaseScheduler"
+
+MONGODB_INDEXING = False
+MONGODB_ASYNC_SAVE = False
